function D = detrend_tp(M)

% D = detrend(M)
%
% fits a plane to the surface defined by the elements of matrix M
% and detrends the surface by subtracting the value of the planar
% fit at each element. Returns the detrended surface in matrix D.
% 
% Dependencies: lsplane.m

% (c) 2007 Taylor Perron

[ny nx] = size(M);

[X Y] = meshgrid(1:nx,1:ny);
[centroid, cosines] = lsplane([X(:) Y(:) M(:)]);

% for a plane with equation z = ax + by + c
a = -cosines(1)/cosines(3);
b = -cosines(2)/cosines(3);
c = centroid(3) + ((cosines(1)*centroid(1) + cosines(2)*centroid(2))/cosines(3));

% at each (x,y) point, subtract the value of the fitted plane from dem
D = M - (a*X + b*Y + c);
